@@ -17,7 +17,10 @@ static const char configKeyDefaultIdentity[] = "Default Identity";
 #include <KEMailSettings> // for IdentityEntry::fromControlCenter()
 #include <KLocalizedString>
 #include <KSharedConfig>
+#include <kcoreaddons_version.h>
+#if KCOREADDONS_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include <Kdelibs4ConfigMigrator>
+#endif
 #include <kuser.h>
 
 #include <QDBusConnection>
@@ -244,7 +247,7 @@ int IdentityManager::Private::newUoid()
     // default identity
 
     do {
-        uoid = QRandomGenerator::global()->generate();
+        uoid = QRandomGenerator::global()->bounded(RAND_MAX);
     } while (usedUOIDs.indexOf(uoid) != -1);
 
     return uoid;
@@ -274,6 +277,7 @@ IdentityManager::IdentityManager(bool readonly, QObject *parent, const char *nam
     : QObject(parent)
     , d(new Private(this))
 {
+#if KCOREADDONS_VERSION < QT_VERSION_CHECK(6, 0, 0)
     static bool triedMigration = false;
     if (!triedMigration) {
         triedMigration = true;
@@ -281,7 +285,7 @@ IdentityManager::IdentityManager(bool readonly, QObject *parent, const char *nam
         migrate.setConfigFiles(QStringList() << QStringLiteral("emailidentities"));
         migrate.migrate();
     }
-
+#endif
     setObjectName(QLatin1String(name));
     new IdentityManagerAdaptor(this);
     QDBusConnection dbus = QDBusConnection::sessionBus();
